ndn-hydra: an NDN distributed repo
==================================

A Named Data Networking (NDN) Distributed Repo implementation using python-ndn_ nicknamed ``hydra``.

Hydra uses ndn-python-svs_ (StateVectorSync) to communicate in a distributed environment.

The implementation is on our github-repo_.

Please see our documentation_.

.. _python-ndn: https://github.com/named-data/python-ndn
.. _ndn-python-svs: https://github.com/justincpresley/ndn-python-svs
.. _documentation: https://ndn-hydra.readthedocs.io
.. _github-repo: https://github.com/UCLA-IRL/ndn-hydra
